@@ -247,12 +247,12 @@ void ApplyChangesWidgetPrivate::createEditPart(const IndexedString & file)
     v->addWidget(changesView);
     v->setSizes(QList<int>() << 400 << 100);
     
-    QObject::connect(m_editParts[m_index], SIGNAL(textChanged(KTextEditor::Document*, KTextEditor::Range, KTextEditor::Range)),
-            parent, SLOT(change (KTextEditor::Document*, KTextEditor::Range, KTextEditor::Range)));
-    QObject::connect(m_editParts[m_index], SIGNAL(textInserted(KTextEditor::Document*, KTextEditor::Range)),
-            parent, SLOT(insertion (KTextEditor::Document*, KTextEditor::Range)));
-    QObject::connect(m_editParts[m_index], SIGNAL(textRemoved(KTextEditor::Document*, KTextEditor::Range, const QString&)),
-            parent, SLOT(removal (KTextEditor::Document*, KTextEditor::Range, const QString&)));
+    QObject::connect(m_editParts[m_index], SIGNAL(textChanged(KTextEditor::Document*,KTextEditor::Range,KTextEditor::Range)),
+            parent, SLOT(change(KTextEditor::Document*,KTextEditor::Range,KTextEditor::Range)));
+    QObject::connect(m_editParts[m_index], SIGNAL(textInserted(KTextEditor::Document*,KTextEditor::Range)),
+            parent, SLOT(insertion(KTextEditor::Document*,KTextEditor::Range)));
+    QObject::connect(m_editParts[m_index], SIGNAL(textRemoved(KTextEditor::Document*,KTextEditor::Range,QString)),
+            parent, SLOT(removal(KTextEditor::Document*,KTextEditor::Range,QString)));
     QObject::connect(changesView, SIGNAL(activated(QModelIndex)),
             parent, SLOT(jump(QModelIndex)));
 }
@@ -270,7 +270,7 @@ void ApplyChangesWidget::insertion(KTextEditor::Document *document, const KTextE
 
 void ApplyChangesWidget::removal(KTextEditor::Document *document, const KTextEditor::Range &range, const QString &oldText)
 {
-    d->addItem(d->m_changes[d->m_index], document, range, i18n("Remove"), oldText);
+    d->addItem(d->m_changes[d->m_index], document, KTextEditor::Range(range.start(), range.start()), i18n("Remove"), oldText);
 }
 
 void ApplyChangesWidget::switchEditView()
