@@ -76,7 +76,7 @@ GrepOutputItem::List grepFile(const QString &filename, const QRegExp &re)
                 SimpleRange(lineno, start, lineno, end),
                 re.cap(0), QString()));
             
-            res << GrepOutputItem(change, data);
+            res << GrepOutputItem(change, data, false);
             offset = end;
         }
         lineno++;
@@ -91,7 +91,7 @@ GrepJob::GrepJob( QObject* parent )
     setCapabilities(Killable);
     KDevelop::ICore::self()->uiController()->registerStatus(this);
     
-    connect(this, SIGNAL(result(KJob *)), this, SLOT(testFinishState(KJob *)));
+    connect(this, SIGNAL(result(KJob*)), this, SLOT(testFinishState(KJob*)));
 }
 
 QString GrepJob::statusName() const
@@ -174,7 +174,7 @@ void GrepJob::slotWork()
             QMetaObject::invokeMethod(this, "slotWork", Qt::QueuedConnection);
             break;
         case WorkCollectFiles:
-            m_findThread = new GrepFindFilesThread(this, m_directory, m_recursiveFlag, m_filesString, m_excludeString, m_useProjectFilesFlag);
+            m_findThread = new GrepFindFilesThread(this, m_directoryChoice, m_recursiveFlag, m_filesString, m_excludeString, m_useProjectFilesFlag);
             emit showMessage(this, i18n("Collecting files..."));
             connect(m_findThread, SIGNAL(finished()), this, SLOT(slotFindFinished()));
             m_findThread->start();
@@ -228,8 +228,8 @@ void GrepJob::start()
     m_outputModel->clear();
 
     qRegisterMetaType<GrepOutputItem::List>();
-    connect(this, SIGNAL(foundMatches(QString, GrepOutputItem::List)),
-            m_outputModel, SLOT(appendOutputs(QString, GrepOutputItem::List)), Qt::QueuedConnection);
+    connect(this, SIGNAL(foundMatches(QString,GrepOutputItem::List)),
+            m_outputModel, SLOT(appendOutputs(QString,GrepOutputItem::List)), Qt::QueuedConnection);
 
     QMetaObject::invokeMethod(this, "slotWork", Qt::QueuedConnection);
 }
@@ -282,9 +282,9 @@ void GrepJob::setExcludeString(const QString& excludeString)
     m_excludeString = excludeString;
 }
 
-void GrepJob::setDirectory(const KUrl& directory)
+void GrepJob::setDirectoryChoice(const QList<KUrl>& choice)
 {
-    m_directory = directory;
+    m_directoryChoice = choice;
 }
 
 void GrepJob::setCaseSensitive(bool caseSensitive)
